import { extname, resolve } from 'path';
import { pathExistsSync } from 'fs-extra';
import { collectImportNames } from "../importIds.cjs";
export function resolveProjectFile(node, program) {
    const importPath = node.moduleSpecifier.text;
    const currentFile = node.getSourceFile().fileName;
    const wantFile = resolve(currentFile, '..', importPath);
    let checkExtensions = ['.ts', '.tsx', extname(currentFile)];
    if (program) {
        if (program.getCompilerOptions().allowJs) {
            checkExtensions.push('.js', '.jsx');
        }
    }
    for (const ext of checkExtensions) {
        if (pathExistsSync(wantFile + ext)) {
            return {
                type: 'typescript',
                identifiers: collectImportNames(node),
                nodeResolve: importPath,
                fsPath: wantFile + ext,
                specifier: importPath,
            };
        }
    }
    return {
        type: 'missing',
        specifier: importPath,
    };
}
//# sourceMappingURL=resolve.tsprogram.js.map