"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.splitPackageName = exports.nodeDiagnosticPosition = exports.createDiagnosticMissingImport = exports.isImportFromNodeModules = exports.isImportNative = exports.getImportedName = void 0;
const module_1 = require("module");
const path_1 = require("path");
function getImportedName(node) {
    return node.moduleSpecifier.text;
}
exports.getImportedName = getImportedName;
function _(node) {
    return typeof node === 'string' ? node : node.moduleSpecifier.text;
}
function isImportNative(node) {
    const importPath = _(node);
    if (module_1.builtinModules) {
        return module_1.builtinModules.includes(importPath);
    }
    try {
        return !require.resolve(importPath).includes('/');
    }
    catch (_a) {
        return false;
    }
}
exports.isImportNative = isImportNative;
function isImportFromNodeModules(node) {
    const importPath = _(node);
    // only when path is not relative
    if (importPath.startsWith('./') || importPath.startsWith('../'))
        return false;
    // TODO: tsconfig resolve
    return true;
}
exports.isImportFromNodeModules = isImportFromNodeModules;
function createDiagnosticMissingImport(node) {
    return `(${nodeDiagnosticPosition(node)}) missing imported "${getImportedName(node)}".`;
}
exports.createDiagnosticMissingImport = createDiagnosticMissingImport;
/**
 * Create something like "xxx/yyy/zzz.ts:111:222"
 */
function nodeDiagnosticPosition(node) {
    let posPart = '';
    try {
        const lines = node
            .getSourceFile()
            .getText()
            .slice(0, node.getStart() + 1)
            .split('\n');
        posPart = ':' + lines.length;
        const last = lines.pop().length;
        posPart += ':' + last;
    }
    catch (_a) { }
    const filePos = path_1.relative(process.cwd(), node.getSourceFile().fileName);
    return `${filePos}${posPart}`;
}
exports.nodeDiagnosticPosition = nodeDiagnosticPosition;
/**
 * split "@some/package/file.js" into "@some/package" and "file.js"
 */
function splitPackageName(path) {
    let i1 = path.indexOf('/');
    if (i1 === -1)
        return { packageName: path, filePath: '.' };
    if (path.startsWith('@')) {
        i1 = path.indexOf('/', i1 + 1);
        if (i1 === -1)
            return { packageName: path, filePath: '.' };
    }
    return { packageName: path.slice(0, i1), filePath: path.slice(i1 + 1) };
}
exports.splitPackageName = splitPackageName;
//# sourceMappingURL=transform.modules.js.map